pub struct Key {
pub segments: Vec<DbKeySeg>,
}Expand description
A storage key is made of storage key segments DbKeySeg, separated by
KEY_SEGMENT_SEPARATOR.
Fields
segments: Vec<DbKeySeg>The segments of the key in the original (left-to-right) order.
Implementations
Sourceimpl Key
impl Key
Sourcepub fn push<T>(&self, other: &T) -> Result<Key, Error>where
T: KeySeg,
pub fn push<T>(&self, other: &T) -> Result<Key, Error>where
T: KeySeg,
Returns a new key with segments of Self and the given segment
Sourcepub fn with_segment<T>(self, other: T) -> Keywhere
T: KeySeg,
pub fn with_segment<T>(self, other: T) -> Keywhere
T: KeySeg,
Takes ownership of the key, appends a new segment to it, and returns the modified key.
Sourcepub fn join(&self, other: &Key) -> Key
pub fn join(&self, other: &Key) -> Key
Returns a new key with segments of Self and the given key
Sourcepub fn find_addresses(&self) -> Vec<Address>
pub fn find_addresses(&self) -> Vec<Address>
Returns the addresses from the key segments
Sourcepub fn fst_address(&self) -> Option<&Address>
pub fn fst_address(&self) -> Option<&Address>
Returns the address from the first key segment if it’s an address.
Sourcepub fn iter_addresses<'k, 'this>(
&'this self,
) -> impl Iterator<Item = &'this Address> + 'kwhere
'this: 'k,
pub fn iter_addresses<'k, 'this>(
&'this self,
) -> impl Iterator<Item = &'this Address> + 'kwhere
'this: 'k,
Iterates over all addresses in the key segments
Sourcepub fn get_at(&self, index: usize) -> Option<&DbKeySeg>
pub fn get_at(&self, index: usize) -> Option<&DbKeySeg>
Return the segment at the index parameter
Sourcepub fn first(&self) -> Option<&DbKeySeg>
pub fn first(&self) -> Option<&DbKeySeg>
Returns the first segment of the key, or None if it is empty.
Sourcepub fn last(&self) -> Option<&DbKeySeg>
pub fn last(&self) -> Option<&DbKeySeg>
Returns the last segment of the key, or None if it is empty.
Sourcepub fn split_last(&self) -> Option<(KeyRef<'_>, &DbKeySeg)>
pub fn split_last(&self) -> Option<(KeyRef<'_>, &DbKeySeg)>
Returns the prefix before the last segment and last segment of the key,
or None if it is empty.
Sourcepub fn wasm_code_name(code_name: String) -> Key
pub fn wasm_code_name(code_name: String) -> Key
Returns a key of wasm code’s hash of the given name
Sourcepub fn wasm_code_len(code_hash: &Hash) -> Key
pub fn wasm_code_len(code_hash: &Hash) -> Key
Returns a key of the wasm code’s length of the given hash
Sourcepub fn wasm_hash(code_path: impl AsRef<str>) -> Key
pub fn wasm_hash(code_path: impl AsRef<str>) -> Key
Returns a key of the wasm code hash of the given code path
Sourcepub fn validity_predicate(addr: &Address) -> Key
pub fn validity_predicate(addr: &Address) -> Key
Returns a key of the validity predicate of the given address Only this function can push “?” segment for validity predicate
Sourcepub fn is_validity_predicate(&self) -> Option<&Address>
pub fn is_validity_predicate(&self) -> Option<&Address>
Check if the given key is a key to a validity predicate. If it is, returns the address of the account.