TransferTarget

Enum TransferTarget 

pub enum TransferTarget {
    Address(Address),
    PaymentAddress(PaymentAddress),
    Ibc(String),
}
Represents a target for the funds of a transfer

Variants



Address(Address)

A transfer going to a transparent address



PaymentAddress(PaymentAddress)

A transfer going to a shielded address



Ibc(String)

A transfer going to an IBC address

Implementations

Source

impl TransferTarget

pub fn effective_address(&self) -> Address

Get the transparent address that this target would effectively go to

pub fn payment_address(&self) -> Option<PaymentAddress>

Get the contained PaymentAddress, if any

pub fn address(&self) -> Option<Address>

Get the contained Address, if any

pub fn t_addr_data(&self) -> Option<TAddrData>

Get the contained TAddrData, if any