MulticallContract

Struct MulticallContract 

pub struct MulticallContract<M>(/* private fields */);

Implementations

Source

impl<M> Multicall3<M>
where M: Middleware,

pub fn new<T>(address: T, client: Arc<M>) -> Multicall3<M>
where T: Into<H160>,

Creates a new contract instance with the specified ethers client at address. The contract derefs to a ethers::Contract object.

pub fn aggregate( &self, calls: Vec<Call>, ) -> FunctionCall<Arc<M>, M, (U256, Vec<Bytes>)>

Calls the contract’s aggregate (0x252dba42) function

pub fn aggregate_3( &self, calls: Vec<Call3>, ) -> FunctionCall<Arc<M>, M, Vec<Result>>

Calls the contract’s aggregate3 (0x82ad56cb) function

pub fn aggregate_3_value( &self, calls: Vec<Call3Value>, ) -> FunctionCall<Arc<M>, M, Vec<Result>>

Calls the contract’s aggregate3Value (0x174dea71) function

pub fn block_and_aggregate( &self, calls: Vec<Call>, ) -> FunctionCall<Arc<M>, M, (U256, [u8; 32], Vec<Result>)>

Calls the contract’s blockAndAggregate (0xc3077fa9) function

pub fn get_basefee(&self) -> FunctionCall<Arc<M>, M, U256>

Calls the contract’s getBasefee (0x3e64a696) function

pub fn get_block_hash( &self, block_number: U256, ) -> FunctionCall<Arc<M>, M, [u8; 32]>

Calls the contract’s getBlockHash (0xee82ac5e) function

pub fn get_block_number(&self) -> FunctionCall<Arc<M>, M, U256>

Calls the contract’s getBlockNumber (0x42cbb15c) function

pub fn get_chain_id(&self) -> FunctionCall<Arc<M>, M, U256>

Calls the contract’s getChainId (0x3408e470) function

pub fn get_current_block_coinbase(&self) -> FunctionCall<Arc<M>, M, H160>

Calls the contract’s getCurrentBlockCoinbase (0xa8b0574e) function

pub fn get_current_block_difficulty(&self) -> FunctionCall<Arc<M>, M, U256>

Calls the contract’s getCurrentBlockDifficulty (0x72425d9d) function

pub fn get_current_block_gas_limit(&self) -> FunctionCall<Arc<M>, M, U256>

Calls the contract’s getCurrentBlockGasLimit (0x86d516e8) function

pub fn get_current_block_timestamp(&self) -> FunctionCall<Arc<M>, M, U256>

Calls the contract’s getCurrentBlockTimestamp (0x0f28c97d) function

pub fn get_eth_balance(&self, addr: H160) -> FunctionCall<Arc<M>, M, U256>

Calls the contract’s getEthBalance (0x4d2301cc) function

pub fn get_last_block_hash(&self) -> FunctionCall<Arc<M>, M, [u8; 32]>

Calls the contract’s getLastBlockHash (0x27e86d6e) function

pub fn try_aggregate( &self, require_success: bool, calls: Vec<Call>, ) -> FunctionCall<Arc<M>, M, Vec<Result>>

Calls the contract’s tryAggregate (0xbce38bd7) function

pub fn try_block_and_aggregate( &self, require_success: bool, calls: Vec<Call>, ) -> FunctionCall<Arc<M>, M, (U256, [u8; 32], Vec<Result>)>

Calls the contract’s tryBlockAndAggregate (0x399542e9) function

Methods from Deref<Target = ContractInstance<Arc<M>, M>>

pub fn address(&self) -> H160

Returns the contract’s address

pub fn abi(&self) -> &Contract

Returns a reference to the contract’s ABI.

pub fn client(&self) -> B
where B: Clone,

Returns a pointer to the contract’s client.

pub fn client_ref(&self) -> &M

Returns a reference to the contract’s client.

pub fn connect<N>(&self, client: Arc<N>) -> ContractInstance<Arc<N>, N>
where N: Middleware,

Returns a new contract instance using the provided client

Clones self internally

pub fn connect_with<C, N>(&self, client: C) -> ContractInstance<C, N>
where C: Borrow<N>,

Returns a new contract instance using the provided client

Clones self internally

pub fn event_with_filter<D>(&self, filter: Filter) -> Event<B, M, D>

Returns an Event builder with the provided filter.

pub fn event<D>(&self) -> Event<B, M, D>
where D: EthEvent,

Returns an Event builder for the provided event.

pub fn event_for_name<D>(&self, name: &str) -> Result<Event<B, M, D>, Error>

Returns an Event builder with the provided name.

pub fn method_hash<T, D>( &self, signature: [u8; 4], args: T, ) -> Result<FunctionCall<B, M, D>, AbiError>
where T: Tokenize, D: Detokenize,

Returns a transaction builder for the selected function signature. This should be preferred if there are overloaded functions in your smart contract

pub fn method<T, D>( &self, name: &str, args: T, ) -> Result<FunctionCall<B, M, D>, AbiError>
where T: Tokenize, D: Detokenize,

Returns a transaction builder for the provided function name. If there are multiple functions with the same name due to overloading, consider using the method_hash method instead, since this will use the first match.

pub fn at<T>(&self, address: T) -> ContractInstance<B, M>
where T: Into<H160>,

Returns a new contract instance at address.

Clones self internally

Methods from Deref<Target = BaseContract>

pub fn encode<T>(&self, name: &str, args: T) -> Result<Bytes, AbiError>
where T: Tokenize,

Returns the ABI encoded data for the provided function and arguments

If the function exists multiple times and you want to use one of the overloaded versions, consider using encode_with_selector

pub fn encode_with_selector<T>( &self, signature: [u8; 4], args: T, ) -> Result<Bytes, AbiError>
where T: Tokenize,

Returns the ABI encoded data for the provided function selector and arguments

pub fn decode<D, T>(&self, name: &str, bytes: T) -> Result<D, AbiError>
where D: Detokenize, T: AsRef<[u8]>,

Decodes the provided ABI encoded function arguments with the selected function name.

If the function exists multiple times and you want to use one of the overloaded versions, consider using decode_with_selector

pub fn decode_raw<T>( &self, name: &str, bytes: T, ) -> Result<Vec<Token>, AbiError>
where T: AsRef<[u8]>,

Decodes the provided ABI encoded function arguments with the selected function name.

If the function exists multiple times and you want to use one of the overloaded versions, consider using decode_with_selector

Returns a Token vector, which lets you decode function arguments dynamically without knowing the return type.

pub fn decode_output<D, T>(&self, name: &str, bytes: T) -> Result<D, AbiError>
where D: Detokenize, T: AsRef<[u8]>,

Decodes the provided ABI encoded function output with the selected function name.

If the function exists multiple times and you want to use one of the overloaded versions, consider using decode_with_selector

pub fn decode_output_raw<T>( &self, name: &str, bytes: T, ) -> Result<Vec<Token>, AbiError>
where T: AsRef<[u8]>,

Decodes the provided ABI encoded function output with the selected function name.

If the function exists multiple times and you want to use one of the overloaded versions, consider using decode_with_selector

Returns a Token vector, which lets you decode function arguments dynamically without knowing the return type.

pub fn decode_event<D>( &self, name: &str, topics: Vec<H256>, data: Bytes, ) -> Result<D, AbiError>
where D: Detokenize,

Decodes for a given event name, given the log.topics and log.data fields from the transaction receipt

pub fn decode_event_raw( &self, name: &str, topics: Vec<H256>, data: Bytes, ) -> Result<Vec<Token>, AbiError>

Decodes for a given event name, given the log.topics and log.data fields from the transaction receipt

Returns a Token vector, which lets you decode function arguments dynamically without knowing the return type.

pub fn decode_with_selector_raw<T>( &self, signature: [u8; 4], bytes: T, ) -> Result<Vec<Token>, AbiError>
where T: AsRef<[u8]>,

Decodes the provided ABI encoded bytes with the selected function selector

Returns a Token vector, which lets you decode function arguments dynamically without knowing the return type.

pub fn decode_with_selector<D, T>( &self, signature: [u8; 4], bytes: T, ) -> Result<D, AbiError>
where D: Detokenize, T: AsRef<[u8]>,

Decodes the provided ABI encoded bytes with the selected function selector

pub fn decode_input_raw<T>(&self, bytes: T) -> Result<Vec<Token>, AbiError>
where T: AsRef<[u8]>,

Decodes the provided ABI encoded input bytes

Returns a Token vector, which lets you decode function arguments dynamically without knowing the return type.

pub fn decode_input<D, T>(&self, bytes: T) -> Result<D, AbiError>
where D: Detokenize, T: AsRef<[u8]>,

Decodes the provided ABI encoded input bytes

pub fn decode_output_with_selector<D, T>( &self, signature: [u8; 4], bytes: T, ) -> Result<D, AbiError>
where D: Detokenize, T: AsRef<[u8]>,

Decode the provided ABI encoded bytes as the output of the provided function selector

pub fn decode_output_with_selector_raw<T>( &self, signature: [u8; 4], bytes: T, ) -> Result<Vec<Token>, AbiError>
where T: AsRef<[u8]>,

Decodes the provided ABI encoded bytes with the selected function selector

Returns a Token vector, which lets you decode function arguments dynamically without knowing the return type.

pub fn abi(&self) -> &Contract

Returns a reference to the contract’s ABI