pub type NoteIndex = BTreeMap<MaspIndexedTx, NotePosition>;Expand description
Maps a shielded tx to the index of its first output note.
Aliased Type
pub struct NoteIndex { /* private fields */ }pub type NoteIndex = BTreeMap<MaspIndexedTx, NotePosition>;Maps a shielded tx to the index of its first output note.
pub struct NoteIndex { /* private fields */ }