Changes

Type Alias Changes 

pub type Changes = Vec<Change>;
A list of changes, which must be applied in the same order to get to the current state.

Aliased Type

pub struct Changes { /* private fields */ }