pub struct WrapperTx {
pub fee: Fee,
pub pk: CommonPublicKey,
pub gas_limit: GasLimit,
}Expand description
A wrapper transaction with some metadata for inclusion and / or verification purposes
Fields
fee: FeeThe fee to be paid for including the tx
pk: CommonPublicKeyUsed for signature verification and to determine an implicit account of the fee payer
gas_limit: GasLimitMax amount of gas that can be used when executing the inner tx
Implementations
Sourceimpl WrapperTx
impl WrapperTx
Sourcepub fn new(fee: Fee, pk: CommonPublicKey, gas_limit: GasLimit) -> WrapperTx
pub fn new(fee: Fee, pk: CommonPublicKey, gas_limit: GasLimit) -> WrapperTx
Create a new wrapper tx from the personal keypair, an optional unshielding tx, and the metadata surrounding the inclusion of the tx.
Sourcepub fn fee_payer(&self) -> Address
pub fn fee_payer(&self) -> Address
Get the address of the implicit account associated with the public key NOTE: this is safe in case someone tried to use the masp address to pay fees. All of the masp funds are kept in the established address, while the implicit one has no funds leading to a tx failure
Sourcepub fn hash<'a>(
&self,
hasher: &'a mut CoreWrapper<CtVariableCoreWrapper<Sha256VarCore, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B0>, B0>, B0>, OidSha256>>,
) -> &'a mut CoreWrapper<CtVariableCoreWrapper<Sha256VarCore, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B0>, B0>, B0>, OidSha256>> ⓘ
pub fn hash<'a>( &self, hasher: &'a mut CoreWrapper<CtVariableCoreWrapper<Sha256VarCore, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B0>, B0>, B0>, OidSha256>>, ) -> &'a mut CoreWrapper<CtVariableCoreWrapper<Sha256VarCore, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B0>, B0>, B0>, OidSha256>> ⓘ
Produce a SHA-256 hash of this section
Sourcepub fn get_tx_fee(&self) -> Result<DenominatedAmount, WrapperTxErr>
pub fn get_tx_fee(&self) -> Result<DenominatedAmount, WrapperTxErr>
Get the DenominatedAmount of fees to be paid by the given wrapper.
Returns an error if the amount overflows