Store

Struct Store 

pub struct Store { /* private fields */ }
A Storage area for keys and addresses

Implementations

Source

impl Store

pub fn find_secret_key( &self, alias_pkh_or_pk: impl AsRef<str>, ) -> Option<&StoredKeypair<SecretKey>>

Find the stored key by an alias, a public key hash or a public key.

pub fn find_public_key( &self, alias_or_pkh: impl AsRef<str>, ) -> Option<&CommonPublicKey>

Find the stored key by an alias, a public key hash or a public key.

pub fn find_spending_key( &self, alias: impl AsRef<str>, ) -> Option<&StoredKeypair<StoreSpendingKey>>

Find the spending key with the given alias and return it

pub fn find_viewing_key( &self, alias: impl AsRef<str>, ) -> Option<&ExtendedViewingKey>

Find the viewing key with the given alias and return it

pub fn find_birthday(&self, alias: impl AsRef<str>) -> Option<&BlockHeight>

Find the birthday of the given alias

pub fn find_diversifier_index( &self, alias: impl AsRef<str>, ) -> Option<&DiversifierIndex>

Find the diversifier of the given alias

pub fn find_payment_addr( &self, alias: impl AsRef<str>, ) -> Option<&PaymentAddress>

Find the payment address with the given alias and return it

pub fn find_alias_by_payment_addr( &self, payment_address: &PaymentAddress, ) -> Option<&Alias>

Find an alias by the address if it’s in the wallet.

pub fn find_key_by_pk( &self, pk: &CommonPublicKey, ) -> Option<&StoredKeypair<SecretKey>>

Find the stored key by a public key.

pub fn find_key_by_pkh( &self, pkh: &PublicKeyHash, ) -> Option<&StoredKeypair<SecretKey>>

Find the stored key by a public key hash.

pub fn find_alias_by_pkh(&self, pkh: &PublicKeyHash) -> Option<Alias>

Find the stored alias for a public key hash.

pub fn find_path_by_pkh(&self, pkh: &PublicKeyHash) -> Option<DerivationPath>

Find a derivation path by public key hash

pub fn find_path_by_viewing_key( &self, viewing_key: &ExtendedViewingKey, ) -> Option<DerivationPath>

Find a derivation path by viewing key

pub fn find_public_key_by_pkh( &self, pkh: &PublicKeyHash, ) -> Option<&CommonPublicKey>

Find the public key by a public key hash.

pub fn find_address(&self, alias: impl AsRef<str>) -> Option<&Address>

Find the stored address by an alias.

pub fn find_alias(&self, address: &Address) -> Option<&Alias>

Find an alias by the address if it’s in the wallet.

pub fn get_secret_keys( &self, ) -> BTreeMap<Alias, (&StoredKeypair<SecretKey>, Option<&PublicKeyHash>)>

Get all known keys by their alias, paired with PKH, if known.

pub fn get_public_keys(&self) -> &BTreeMap<Alias, CommonPublicKey>

Get all known public keys by their alias.

pub fn get_addresses(&self) -> &BiBTreeMap<Alias, Address>

Get all known addresses by their alias.

pub fn get_payment_addrs(&self) -> &BiBTreeMap<Alias, PaymentAddress>

Get all known payment addresses by their alias.

pub fn get_viewing_keys(&self) -> &BTreeMap<Alias, ExtendedViewingKey>

Get all known viewing keys by their alias.

pub fn get_spending_keys( &self, ) -> &BTreeMap<Alias, StoredKeypair<StoreSpendingKey>>

Get all known spending keys by their alias.

pub fn add_validator_data(&mut self, address: Address, keys: ValidatorKeys)

Add validator data to the store

pub fn get_validator_data(&self) -> Option<&ValidatorData>

Returns a reference to the validator data, if it exists.

pub fn get_validator_data_mut(&mut self) -> Option<&mut ValidatorData>

Returns a mut reference to the validator data, if it exists.

pub fn take_validator_data(&mut self) -> Option<ValidatorData>

Take the validator data, if it exists.

pub fn into_validator_data(self) -> Option<ValidatorData>

Returns the validator data, if it exists.

pub fn insert_keypair<U>( &mut self, alias: Alias, keypair: SecretKey, password: Option<Zeroizing<String>>, address: Option<Address>, path: Option<DerivationPath>, force: bool, ) -> Option<Alias>
where U: WalletIo,

Insert a new secret key with the given alias. If the alias is already used, will prompt for overwrite/reselection confirmation. If declined, then keypair is not inserted and nothing is returned, otherwise selected alias is returned.

pub fn insert_spending_key<U>( &mut self, alias: Alias, spendkey: ExtendedSpendingKey, birthday: Option<BlockHeight>, password: Option<Zeroizing<String>>, path: Option<DerivationPath>, force: bool, ) -> Option<Alias>
where U: WalletIo,

Insert spending keys similarly to how it’s done for keypairs

pub fn insert_viewing_key<U>( &mut self, alias: Alias, viewkey: ExtendedViewingKey, birthday: Option<BlockHeight>, path: Option<DerivationPath>, force: bool, ) -> Option<Alias>
where U: WalletIo,

Insert viewing keys similarly to how it’s done for keypairs

pub fn insert_public_key<U>( &mut self, alias: Alias, pubkey: CommonPublicKey, address: Option<Address>, path: Option<DerivationPath>, force: bool, ) -> Option<Alias>
where U: WalletIo,

Insert public keys

pub fn insert_payment_addr<U>( &mut self, alias: Alias, payment_addr: PaymentAddress, force: bool, ) -> Option<Alias>
where U: WalletIo,

Insert payment addresses similarly to how it’s done for keypairs

pub fn insert_diversifier_index( &mut self, alias: Alias, div_index: DiversifierIndex, ) -> Option<Alias>

Insert the given diversifier index under the given alias. Useful for sequential payment address generation.

pub fn insert_address<U>( &mut self, alias: Alias, address: Address, force: bool, ) -> Option<Alias>
where U: WalletIo,

Insert a new address with the given alias. If the alias is already used, will prompt for overwrite/reselection confirmation, which when declined, the address won’t be added. Return the selected alias if the address has been added.

pub fn contains_alias(&self, alias: &Alias) -> bool

Check if any map of the wallet contains the given alias

pub fn remove_alias(&mut self, alias: &Alias)

Completely remove the given alias from all maps in the wallet

pub fn extend(&mut self, store: Store)

Extend this store from another store (typically pre-genesis). Note that this method ignores validator_data if any.

pub fn extend_from_pre_genesis_validator( &mut self, validator_address: Address, validator_alias: Alias, other: ValidatorWallet, )

Extend this store from pre-genesis validator wallet.

pub fn get_addresses_with_vp_type( &self, vp_type: AddressVpType, ) -> IndexSet<Address>

get an address with the vp type

pub fn add_vp_type_to_address( &mut self, vp_type: AddressVpType, address: Address, )

Adds a VP type to the address

pub fn decode(data: &str) -> Result<Store, Error>

Decode a Store from the given string

pub fn encode(&self) -> String

Encode a store into a string